## Polynomial defined in appendix C of Villemot (2004)
K.R <- function(n, d, r)
{
  if (r == 0)
    (n-1)/2 + d
  else
    {
      R <- 1/(1+r)
      1/(1-R) - R^d*(1-R^n)/(n*(1-R)^2)
    }
}

## Table C.1 page 43 of Villemot (2004)
K.R.make.table <- function()
{
  results <- numeric()
  for (years in 1:10)
  {
    for (r in c(0, 0.01, 0.02, 0.03, 0.04, 0.05))
      results <- c(results, K.R(years, 1, r))
  }
  dim(results) <- c(6, 10)
  rownames(results) <- c("0%", "1%", "2%", "3%", "4%", "5%")
  colnames(results) <- 1:10
  results
}

## Table 3.1 page 20 of Villemot (2004)
R.K.R.make.table <- function()
{
  results <- numeric()
  for (years in 1:10)
  {
    for (r in c(0, 0.01, 0.02, 0.03, 0.04, 0.05))
      results <- c(results, K.R(years, 1, r) / (1+r))
  }
  dim(results) <- c(6, 10)
  rownames(results) <- c("0%", "1%", "2%", "3%", "4%", "5%")
  colnames(results) <- 1:10
  results
}
