# Nécessite top.R

# Si diff = TRUE, calcule c1 moins sa MA
# Si diff = FALSE, donne juste la MA
ma.annual <- function(c1, years, delay, diff = FALSE)
{
  st <- start(c1)
  st[1] <- st[1] - (years + delay - 1)

  ed <- end(c1)

  c2 <- ts(c(rep(c1[1], years + delay - 1), c1), start=st, end=ed, frequency=1)

  f <- c(rep(0, delay), rep(1/years, years))

  if (diff)
    {
      f <- -f
      f[1] <- f[1] + 1
    }

  na.contiguous(filter(c2, f, sides = 1))
}

ma.monthly <- function(c1, months, delay)
{
  st <- start(c1)
  sst <- st[1] * 12 + (st[2] - 1) - (months+delay-1)
  st <- c(as.integer(sst / 12), (sst %% 12) + 1)

  ed <- end(c1)
  eed <- ed[1] * 12 + (ed[2] - 1) - delay
  ed <- c(as.integer(eed / 12), (eed %% 12) + 1)

  # Attention à ça, c discutable..!  
  if (delay == 0)
    init <- c1[1]
  else
    init <- sum(c1[1:delay]) / delay

  c2 <- ts(c(rep(init, months+delay-1), c1), start=st, end=ed, frequency=12)

  c3 <- lag(c2, -delay)
  if (months > 1)
  {
    for (i in 1:(months-1))
      {
        c3 <- c3 + lag(c2, -(delay+i))
      }
    c3 <- c3 / months
  }
  c3
}

# bw = TRUE pour avoir en noir et blanc
make.graph <- function(comm, bw = TRUE, path = "/tmp", width = 1280, height = 1024, english = TRUE, axis.legend = FALSE, transparent.bg = FALSE, pointsize = 24)
{
  if (english)
    leg <- c("Monthly spot prices", "MA over 2 years", "MA over 5 years", "MA over 10 years")
  else
    leg <- c("Prix au comptant mensuels", "MM sur 2 ans", "MM sur 5 ans", "MM sur 10 ans")    

  X11(width = 12.8, height = 10.24, pointsize = pointsize)

  if (transparent.bg)
    par(bg="transparent")
  else
    par(bg="white")

  lwds <- rep(2, 4)

  if (bw)
    {
      cols <- rep("black", 4)
      ltys <- c(1, 2, 4, 3)
    }
  else
    {
      cols <- c("black", "blue", "green", "red")
      ltys <- rep(1, 4)
    }

  if (axis.legend)
    {
     tt <- paste(commodities.infos[comm, "names"], " -", commodities.infos[comm, "comments"], sep="")
     yl <- paste("Real prices (base=", ref.year, "), ", commodities.infos[comm, "units"], sep="")
     xl <- "Time"
    }
  else
    {
      tt <- ""
      yl <- ""
      xl <- ""
      par(mar = c(2.5,2.5,2.5,2.5))
    }

  c <- get.level.monthly.data(comm)

  plot(c, main = tt, xlab = xl, ylab = yl, col = cols[1], lty = ltys[1], lwd = lwds[1])
  lines(ma.monthly(c, 24, 12), col = cols[2], lty = ltys[2], lwd = lwds[2])
  lines(ma.monthly(c, 60, 12), col = cols[3], lty = ltys[3], lwd = lwds[3])
  lines(ma.monthly(c, 120, 12), col = cols[4], lty = ltys[4], lwd = lwds[4])
  legend(locator(1), leg, col = cols, lty = ltys, lwd = lwds, bty = "n")

  dev.print(device=png, file=paste(path, "/", comm.names[[comm]], ".png", sep=""), width = width, height = height, pointsize = pointsize)

  dev.off()
}
